<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk">
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="80"/>
        <source>Skip forward in playlist</source>
        <translation>Posunúť sa v plaliste</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="81"/>
        <source>Skip backwards in playlist</source>
        <translation>Vrátiť sa v playliste</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="72"/>
        <source>Start playing current song</source>
        <translation>Začať prehrávanie súčasnej piesne</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="71"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Nevyčisťovať playlist</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="73"/>
        <source>Pause current song</source>
        <translation>Pozastaviť súčasnú pieseň</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="74"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pozastaviť ak hrá, inak hrať</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="75"/>
        <source>Stop current song</source>
        <translation>Zastaviť súčasnú pieseň</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="76"/>
        <source>Display Jump to File dialog</source>
        <translation>Zobraziť dialóg Preskočiť na súbor</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="77"/>
        <source>Quit application</source>
        <translation>Ukončiť program</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="78"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Nastaviť hlasitosť prehrávania (napríklad: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="79"/>
        <source>Mute/Restore volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="82"/>
        <source>Show/hide application</source>
        <translation>Zobraziť/skryť program</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="83"/>
        <source>Show main window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="84"/>
        <source>Display Add File dialog</source>
        <translation>Zobraziť dialóg Pridať súbor</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="85"/>
        <source>Display Add Directory dialog</source>
        <translation>Zobraziť dialóg Pridať priečinok</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="315"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Použitie: qmmp [možnosti] [súbory]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="316"/>
        <source>Options:</source>
        <translation>Možnosti:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="320"/>
        <source>Don&apos;t start the application</source>
        <translation>Nezapnúť program</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="322"/>
        <source>Print version number and exit</source>
        <translation>Vypísať číslo verzie a skončiť</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="323"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Nápady, záplaty, hlásenie chýb posílejte na forkotov02@hotmail.ru (anglicky)</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="326"/>
        <source>Command Line Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="339"/>
        <source>QMMP version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="340"/>
        <source>Compiled with Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="341"/>
        <source>Using Qt version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="344"/>
        <source>Qmmp Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="321"/>
        <source>Display this text and exit</source>
        <translation>Zobraziť tento text a skončiť</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="88"/>
        <source>Unknown command</source>
        <translation>Neznámý príkaz</translation>
    </message>
</context>
</TS>
